@@ -3,6 +3,8 @@ from paver.easy import *
 from paver.setuputils import setup
 #from setuptools import setup
 from setuptools import find_packages
+import sys
+sys.path.append('./src')
 import neuronvisio
 
 try:
@@ -45,6 +47,8 @@ setup(
     version=version,
     description='NeuronVisio is a Graphical User Interface for NEURON simulator enviroment',
     long_description=open('README.rst', 'r').read(),
+    package_dir={'neuronvisio': 'src'},
+    scripts= ['src/nrnvisio'],
     classifiers=classifiers,
     keywords='neuron, gui, pylab, 3D, visualization',
     author='Michele Mattioni',
@@ -86,7 +90,7 @@ options(
     )
 
 options.setup.package_data=paver.setuputils.find_package_data(
-    'neuronvisio', package='neuronvisio', only_in_packages=False)
+    'src', package='neuronvisio', only_in_packages=False)
 
 if ALL_TASKS_LOADED:
     @task
